finchan.exts.timer_source
==================================

.. automodule:: finchan.exts.timer_source

   JobMananger
   --------------------
   .. autoclass:: JobMananger
       :members:

   Job
   --------------------
   .. autoclass:: Job
       :members:

   LiveTimerSource
   --------------------
   .. autoclass:: LiveTimerSource
       :members:

   BackTimerSource
   --------------------
   .. autoclass:: BackTimerSource
       :members:
